/*
    This file is part of Icecream.

    Copyright (c) 2006 Mirko Boehm <mirko@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#ifndef PLATFORM_H
#define PLATFORM_H

#include <string>

extern const std::string& determine_platform();

extern int ggc_min_expand_heuristic(unsigned int mem_limit);
extern unsigned int ggc_min_heapsize_heuristic(unsigned int mem_limit);

#endif
